function [ret,x0,str,ts,xts]=boussol6(t,x,u,flag);
%BOUSSOL6	is the M-file description of the SIMULINK system named BOUSSOL6.
%	The block-diagram can be displayed by typing: BOUSSOL6.
%
%	SYS=BOUSSOL6(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BOUSSOL6 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BOUSSOL6 with a FLAG of zero:
%	[SIZES]=BOUSSOL6([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1267,947])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '6000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')

add_block('built-in/Note',[sys,'/',['SIMULATION TOTALE1.M DEVANT FINIR CASAASAT.m',13,'']])
set_param([sys,'/',['SIMULATION TOTALE1.M DEVANT FINIR CASAASAT.m',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[700,60,705,65])


%     Subsystem  'Graphiques'.

new_system([sys,'/','Graphiques'])
set_param([sys,'/','Graphiques'],'Location',[25,6553675,1165,6554120])


%     Subsystem  'Graphiques/Extras27'.

new_system([sys,'/','Graphiques/Extras27'])
set_param([sys,'/','Graphiques/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras27'.

set_param([sys,'/','Graphiques/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,240,220,301])


%     Subsystem  'Graphiques/Extras22'.

new_system([sys,'/','Graphiques/Extras22'])
set_param([sys,'/','Graphiques/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras22'.

set_param([sys,'/','Graphiques/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphiques/Extras29'.

new_system([sys,'/','Graphiques/Extras29'])
set_param([sys,'/','Graphiques/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras29'.

set_param([sys,'/','Graphiques/Extras29'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphiques/Extras21'.

new_system([sys,'/','Graphiques/Extras21'])
set_param([sys,'/','Graphiques/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras21'.

set_param([sys,'/','Graphiques/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphiques/Extras20'.

new_system([sys,'/','Graphiques/Extras20'])
set_param([sys,'/','Graphiques/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras20'.

set_param([sys,'/','Graphiques/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])

add_block('built-in/Note',[sys,'/','Graphiques/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphiques/SORTIES GRAPHIQUES'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,50,530,55])


%     Subsystem  'Graphiques/Extras30'.

new_system([sys,'/','Graphiques/Extras30'])
set_param([sys,'/','Graphiques/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras30'.

set_param([sys,'/','Graphiques/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphiques/Extras34'.

new_system([sys,'/','Graphiques/Extras34'])
set_param([sys,'/','Graphiques/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras34'.

set_param([sys,'/','Graphiques/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphiques/Extras32'.

new_system([sys,'/','Graphiques/Extras32'])
set_param([sys,'/','Graphiques/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras32'.

set_param([sys,'/','Graphiques/Extras32'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphiques/Extras23'.

new_system([sys,'/','Graphiques/Extras23'])
set_param([sys,'/','Graphiques/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras23'.

set_param([sys,'/','Graphiques/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphiques/Extras24'.

new_system([sys,'/','Graphiques/Extras24'])
set_param([sys,'/','Graphiques/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras24'.

set_param([sys,'/','Graphiques/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphiques/Extras25'.

new_system([sys,'/','Graphiques/Extras25'])
set_param([sys,'/','Graphiques/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras25'.

set_param([sys,'/','Graphiques/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphiques/Extras26'.

new_system([sys,'/','Graphiques/Extras26'])
set_param([sys,'/','Graphiques/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphiques/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphiques/Extras26'.

set_param([sys,'/','Graphiques/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphiques/Extras28'.

new_system([sys,'/','Graphiques/Extras28'])
set_param([sys,'/','Graphiques/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras28'.

set_param([sys,'/','Graphiques/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphiques/Extras31'.

new_system([sys,'/','Graphiques/Extras31'])
set_param([sys,'/','Graphiques/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras31'.

set_param([sys,'/','Graphiques/Extras31'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphiques/Extras33'.

new_system([sys,'/','Graphiques/Extras33'])
set_param([sys,'/','Graphiques/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras33'.

set_param([sys,'/','Graphiques/Extras33'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])
set_param([sys,'/','Graphiques'],...
		'Mask Display','SORTIES|\n\nGRAPHIQUES')


%     Finished composite block 'Graphiques'.

set_param([sys,'/','Graphiques'],...
		'position',[1275,730,1530,786])

add_block('built-in/Note',[sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']])
set_param([sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[703,5,708,10])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[685,90,690,95])

add_block('built-in/Note',[sys,'/','CHAMP MAGNETIQUE REEL ( Sans tenir compte de la copntrainte de la mesure )'])
set_param([sys,'/','CHAMP MAGNETIQUE REEL ( Sans tenir compte de la copntrainte de la mesure )'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[655,135,660,140])


%     Subsystem  'Hacheur'.

new_system([sys,'/','Hacheur'])
set_param([sys,'/','Hacheur'],'Location',[307,509,982,814])

add_block('built-in/Gain',[sys,'/','Hacheur/Gain1'])
set_param([sys,'/','Hacheur/Gain1'],...
		'hide name',0,...
		'Gain','non_pulse',...
		'position',[220,170,355,210])

add_block('built-in/Sum',[sys,'/','Hacheur/Sum1'])
set_param([sys,'/','Hacheur/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','Hacheur/Gain2'])
set_param([sys,'/','Hacheur/Gain2'],...
		'hide name',0,...
		'Gain','1-non_pulse',...
		'position',[340,90,475,130])


%     Subsystem  'Hacheur/Subsystem5'.

new_system([sys,'/','Hacheur/Subsystem5'])
set_param([sys,'/','Hacheur/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/Note',[sys,'/','Hacheur/Subsystem5/CRENEAU'])
set_param([sys,'/','Hacheur/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/Outport',[sys,'/','Hacheur/Subsystem5/out_1'])
set_param([sys,'/','Hacheur/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/','Hacheur/Subsystem5/Product'])
set_param([sys,'/','Hacheur/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Inport',[sys,'/','Hacheur/Subsystem5/in_1'])
set_param([sys,'/','Hacheur/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/MATLAB Fcn',[sys,'/','Hacheur/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','Hacheur/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Clock',[sys,'/','Hacheur/Subsystem5/Clock'])
set_param([sys,'/','Hacheur/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])
add_line([sys,'/','Hacheur/Subsystem5'],[140,85;225,85])
add_line([sys,'/','Hacheur/Subsystem5'],[255,110;290,110])
add_line([sys,'/','Hacheur/Subsystem5'],[185,130;225,130])
add_line([sys,'/','Hacheur/Subsystem5'],[85,130;115,130])
set_param([sys,'/','Hacheur/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'Hacheur/Subsystem5'.

set_param([sys,'/','Hacheur/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Outport',[sys,'/','Hacheur/out_1'])
set_param([sys,'/','Hacheur/out_1'],...
		'position',[575,140,595,160])

add_block('built-in/To Workspace',[sys,'/','Hacheur/To Workspace1'])
set_param([sys,'/','Hacheur/To Workspace1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','test0',...
		'buffer','points_trace',...
		'position',[430,57,480,73])

add_block('built-in/Inport',[sys,'/','Hacheur/in_1'])
set_param([sys,'/','Hacheur/in_1'],...
		'position',[65,100,85,120])
add_line([sys,'/','Hacheur'],[90,110;185,110])
add_line([sys,'/','Hacheur'],[90,110;125,110;125,190;215,190])
add_line([sys,'/','Hacheur'],[480,110;520,110])
add_line([sys,'/','Hacheur'],[360,190;520,190])
add_line([sys,'/','Hacheur'],[320,110;335,110])
add_line([sys,'/','Hacheur'],[550,150;570,150])
add_line([sys,'/','Hacheur'],[500,110;500,65;485,65])
set_param([sys,'/','Hacheur'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'Hacheur'.

set_param([sys,'/','Hacheur'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[460,288,605,342])


%     Subsystem  'Stops'.

new_system([sys,'/','Stops'])
set_param([sys,'/','Stops'],'Location',[4,215,1115,867])

add_block('built-in/Demux',[sys,'/','Stops/Demux1'])
set_param([sys,'/','Stops/Demux1'],...
		'outputs','[3 3]',...
		'position',[230,207,270,263])

add_block('built-in/MATLAB Fcn',[sys,'/','Stops/fpqrQ_V_P1'])
set_param([sys,'/','Stops/fpqrQ_V_P1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'Mask Display','pqrQ_V_P',...
		'position',[135,214,205,256])

add_block('built-in/Note',[sys,'/',['Stops/Le stop angulaire ne devient effectif qu''aprs que celui des vitesses le soit devenu',13,'ce qui signifie qu'' la fois angles et vitesses sont au dessous des seuils']])
set_param([sys,'/',['Stops/Le stop angulaire ne devient effectif qu''aprs que celui des vitesses le soit devenu',13,'ce qui signifie qu'' la fois angles et vitesses sont au dessous des seuils']],...
		'ForeGround',1,...
		'Font Name','Arial')
set_param([sys,'/',['Stops/Le stop angulaire ne devient effectif qu''aprs que celui des vitesses le soit devenu',13,'ce qui signifie qu'' la fois angles et vitesses sont au dessous des seuils']],...
		'Font Size',14)
set_param([sys,'/',['Stops/Le stop angulaire ne devient effectif qu''aprs que celui des vitesses le soit devenu',13,'ce qui signifie qu'' la fois angles et vitesses sont au dessous des seuils']],...
		'position',[630,485,635,490])


%     Subsystem  'Stops/Stop detumbling3'.

new_system([sys,'/','Stops/Stop detumbling3'])
set_param([sys,'/','Stops/Stop detumbling3'],'Location',[724,654,1159,757])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling3/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling3/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling3/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling3/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling3/Gain'])
set_param([sys,'/','Stops/Stop detumbling3/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling3/in_1'])
set_param([sys,'/','Stops/Stop detumbling3/in_1'],...
		'position',[130,55,150,75])
add_line([sys,'/','Stops/Stop detumbling3'],[315,65;345,65])
add_line([sys,'/','Stops/Stop detumbling3'],[155,65;225,65])
set_param([sys,'/','Stops/Stop detumbling3'],...
		'Mask Display','STOP DU MODE "Bpoint"\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling3'.

set_param([sys,'/','Stops/Stop detumbling3'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[870,353,1085,407])


%     Subsystem  'Stops/Stop detumbling2'.

new_system([sys,'/','Stops/Stop detumbling2'])
set_param([sys,'/','Stops/Stop detumbling2'],'Location',[769,541,1204,644])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling2/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling2/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling2/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling2/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling2/Gain'])
set_param([sys,'/','Stops/Stop detumbling2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling2/in_1'])
set_param([sys,'/','Stops/Stop detumbling2/in_1'],...
		'position',[130,55,150,75])
add_line([sys,'/','Stops/Stop detumbling2'],[315,65;345,65])
add_line([sys,'/','Stops/Stop detumbling2'],[155,65;225,65])
set_param([sys,'/','Stops/Stop detumbling2'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling2'.

set_param([sys,'/','Stops/Stop detumbling2'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[880,175,1075,225])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil de vitesse'])
set_param([sys,'/','Stops/Contrle du seuil de vitesse'],...
		'ForeGround',1,...
		'position',[650,390,655,395])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil angulaire'])
set_param([sys,'/','Stops/Contrle du seuil angulaire'],...
		'ForeGround',1,...
		'position',[655,155,660,160])

add_block('built-in/Product',[sys,'/','Stops/Product'])
set_param([sys,'/','Stops/Product'],...
		'position',[750,169,775,231])

add_block('built-in/Note',[sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']])
set_param([sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[415,25,420,30])

add_block('built-in/Note',[sys,'/','Stops/La'])
set_param([sys,'/','Stops/La'],...
		'position',[205,65,210,70])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator2']])
set_param([sys,'/',['Stops/Relational',13,'Operator2']],...
		'position',[510,303,550,452])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator1']])
set_param([sys,'/',['Stops/Relational',13,'Operator1']],...
		'position',[505,108,545,257])

add_block('built-in/Constant',[sys,'/','Stops/Constant3'])
set_param([sys,'/','Stops/Constant3'],...
		'Value','vitesse_angul_mini',...
		'position',[310,329,480,351])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles2']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil  vitesse angulaire')
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'position',[330,390,465,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles1']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil angulaire',...
		'position',[335,196,430,244])

add_block('built-in/Constant',[sys,'/','Stops/Constant2'])
set_param([sys,'/','Stops/Constant2'],...
		'Value','angle_mini_mod_fin',...
		'position',[270,134,440,156])

add_block('built-in/Inport',[sys,'/','Stops/in_1'])
set_param([sys,'/','Stops/in_1'],...
		'position',[75,225,95,245])
add_line([sys,'/','Stops'],[780,200;875,200])
add_line([sys,'/','Stops'],[555,380;865,380])
add_line([sys,'/','Stops'],[650,380;650,215;745,215])
add_line([sys,'/','Stops'],[550,185;745,185])
add_line([sys,'/','Stops'],[485,340;505,340])
add_line([sys,'/','Stops'],[470,415;505,415])
add_line([sys,'/','Stops'],[275,250;300,250;300,415;325,415])
add_line([sys,'/','Stops'],[275,220;330,220])
add_line([sys,'/','Stops'],[435,220;500,220])
add_line([sys,'/','Stops'],[445,145;500,145])
add_line([sys,'/','Stops'],[210,235;225,235])
add_line([sys,'/','Stops'],[100,235;130,235])
set_param([sys,'/','Stops'],...
		'Mask Display','STOP DE SIMULATION\nSUR SEUIL ANGULAIRE\n( angle mini_mod_fin )')


%     Finished composite block 'Stops'.

set_param([sys,'/','Stops'],...
		'hide name',0,...
		'position',[1010,389,1210,441])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[860,424,960,476])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'hide name',0,...
		'position',[60,355,80,375])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\n(totdatNP.m)\n par double clic souris\nCAS NON PULSE',...
		'Mask Dialogue','eval(''puldatNP'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1015,470,1230,561])

add_block('built-in/Note',[sys,'/','Hcheur'])
set_param([sys,'/','Hcheur'],...
		'position',[550,260,555,265])


%     Subsystem  'Couplage roue-satellite'.

new_system([sys,'/','Couplage roue-satellite'])
set_param([sys,'/','Couplage roue-satellite'],'Location',[90,50,975,400])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'])
set_param([sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'],...
		'ForeGround',3,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[530,50,535,55])

add_block('built-in/Note',[sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']])
set_param([sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']],...
		'position',[715,205,720,210])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'])
set_param([sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'],...
		'position',[495,215,500,220])

add_block('built-in/Mux',[sys,'/','Couplage roue-satellite/Mux'])
set_param([sys,'/','Couplage roue-satellite/Mux'],...
		'inputs','[1 7]',...
		'position',[285,108,340,252])

add_block('built-in/Outport',[sys,'/','Couplage roue-satellite/out_1'])
set_param([sys,'/','Couplage roue-satellite/out_1'],...
		'position',[680,170,700,190])

add_block('built-in/MATLAB Fcn',[sys,'/','Couplage roue-satellite/magneto.m2'])
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue\nau second membre')
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'position',[415,156,555,204])

add_block('built-in/Gain',[sys,'/','Couplage roue-satellite/Gain1'])
set_param([sys,'/','Couplage roue-satellite/Gain1'],...
		'hide name',0,...
		'position',[600,167,625,193])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/pqrQ'])
set_param([sys,'/','Couplage roue-satellite/pqrQ'],...
		'position',[190,195,195,200])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_4'])
set_param([sys,'/','Couplage roue-satellite/in_4'],...
		'Port','2',...
		'position',[210,204,235,226])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_3'])
set_param([sys,'/','Couplage roue-satellite/in_3'],...
		'position',[205,135,225,155])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Vitesseroue'])
set_param([sys,'/','Couplage roue-satellite/Vitesseroue'],...
		'position',[190,105,195,110])
add_line([sys,'/','Couplage roue-satellite'],[345,180;410,180])
add_line([sys,'/','Couplage roue-satellite'],[230,145;280,145])
add_line([sys,'/','Couplage roue-satellite'],[240,215;280,215])
add_line([sys,'/','Couplage roue-satellite'],[560,180;595,180])
add_line([sys,'/','Couplage roue-satellite'],[630,180;675,180])
set_param([sys,'/','Couplage roue-satellite'],...
		'Mask Display','COUPLAGE ROUE-SATELLITE')


%     Finished composite block 'Couplage roue-satellite'.

set_param([sys,'/','Couplage roue-satellite'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[135,447,370,503])


%     Subsystem  'Bloc de Laurens 1'.

new_system([sys,'/','Bloc de Laurens 1'])
set_param([sys,'/','Bloc de Laurens 1'],'Location',[86,120,1041,657])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/REGULATION EN "BPOINT" + RAPPEL SUR',13,'CHAMP CONSIGNE+ ROUE']])
set_param([sys,'/',['Bloc de Laurens 1/REGULATION EN "BPOINT" + RAPPEL SUR',13,'CHAMP CONSIGNE+ ROUE']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,45,530,50])

add_block('built-in/Inport',[sys,'/','Bloc de Laurens 1/Inport'])
set_param([sys,'/','Bloc de Laurens 1/Inport'],...
		'position',[80,205,100,225])

add_block('built-in/Inport',[sys,'/','Bloc de Laurens 1/Inport1'])
set_param([sys,'/','Bloc de Laurens 1/Inport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[80,305,100,325])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Coupure du calcul',13,'couple roue en mode Bpoint']])
set_param([sys,'/',['Bloc de Laurens 1/Coupure du calcul',13,'couple roue en mode Bpoint']],...
		'ForeGround',1,...
		'position',[305,313,310,318])

add_block('built-in/Product',[sys,'/','Bloc de Laurens 1/Product'])
set_param([sys,'/','Bloc de Laurens 1/Product'],...
		'position',[790,279,820,326])

add_block('built-in/Outport',[sys,'/','Bloc de Laurens 1/out_1'])
set_param([sys,'/','Bloc de Laurens 1/out_1'],...
		'position',[865,295,885,315])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/To Workspace1'])
set_param([sys,'/','Bloc de Laurens 1/To Workspace1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','test4',...
		'buffer','points_trace',...
		'position',[775,362,825,378])


%     Subsystem  'Bloc de Laurens 1/Calcul des commandes, moments et roue'.

new_system([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],'Location',[92,50,1253,732])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Weight','bold',...
		'Font Size',18)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'position',[555,10,560,15])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Champ rel'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Champ rel'],...
		'position',[625,365,630,370])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],'Location',[442,254,1087,515])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/in_1']],...
		'hide name',0,...
		'position',[25,100,45,120])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_3']],...
		'hide name',0,...
		'Port','3',...
		'position',[360,130,380,150])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_2']],...
		'hide name',0,...
		'position',[360,70,380,90])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/out_1']],...
		'hide name',0,...
		'Port','2',...
		'position',[360,100,380,120])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],'Location',[4,192,1154,487])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']],...
		'Port','3',...
		'position',[760,185,780,205])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']],...
		'Port','2',...
		'position',[760,145,780,165])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']],...
		'position',[760,105,780,125])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],'Location',[154,322,1099,787])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']],...
		'position',[115,190,135,210])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']],...
		'position',[690,55,695,60])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']],...
		'position',[790,425,795,430])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']],...
		'position',[800,390,820,410])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']],...
		'Port','3',...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']],...
		'Port','2',...
		'position',[790,145,810,165])

add_block('built-in/Sum',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']],...
		'hide name',0,...
		'position',[640,134,665,321])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']],...
		'Port','2',...
		'position',[95,250,115,270])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])

add_block('built-in/Sum',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'Output Width','1')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'position',[705,568,825,602])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/To File',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'position',[635,134,730,166])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'position',[515,208,575,242])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'position',[630,268,750,302])

add_block('built-in/Constant',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/Relational Operator',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Mux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Size',12)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'position',[420,45,425,50])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[120,260;150,260])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[300,260;370,260])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'position',[310,260,445,340])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']],...
		'hide name',0,...
		'position',[410,385,415,390])

add_block('built-in/Product',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']],...
		'position',[535,227,560,323])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],'Location',[198,215,1097,749])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']],...
		'Port','2',...
		'position',[615,220,635,240])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Mux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'position',[505,213,565,247])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Relational Operator',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/Constant',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],'Location',[163,376,803,621])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']],...
		'position',[555,105,575,125])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Size',12)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[135,100,140,105])

add_block('built-in/Sum',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'Output Width','1')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[500,115;550,115])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Clock',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']],...
		'hide name',0,...
		'position',[45,330,85,370])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Name','Arial')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Size',14)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[390,220;390,110;610,110])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[285,350;370,350])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'position',[300,165,435,235])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']],...
		'position',[495,270,500,275])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']],...
		'position',[535,335,540,340])

add_block('built-in/Derivative',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']],...
		'position',[500,225,505,230])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']],...
		'position',[130,285,135,290])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']],...
		'Port','2',...
		'position',[110,310,130,330])

add_block('built-in/Demux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']],...
		'outputs','3',...
		'position',[505,94,545,126])

add_block('built-in/Demux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']],...
		'outputs','3',...
		'position',[680,349,720,381])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'hide name',0,...
		'mat-name','b_reel_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'position',[580,84,660,116])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'hide name',0,...
		'mat-name','derb_pulse_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'position',[755,339,870,371])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','points_trace')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'position',[745,213,865,247])

add_block('built-in/Demux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']],...
		'outputs','3',...
		'position',[750,279,790,311])

add_block('built-in/Demux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']],...
		'outputs','3',...
		'position',[375,419,415,451])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'hide name',0,...
		'mat-name','derb_reel_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'position',[460,409,540,441])

add_block('built-in/To Workspace',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'hide name',0,...
		'mat-name','b_pulse_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'position',[825,266,925,304])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[670,230;740,230])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[685,230;685,155;785,155])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[450,300;530,300])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[475,300;475,400;795,400])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,175;465,175;465,55;775,55])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[135,320;305,320])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;305,280])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[565,275;635,275])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,225;455,225;455,250;530,250])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,200;580,200;580,180;635,180])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[140,200;295,200])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[275,200;190,200;190,280;225,280])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[465,110;500,110])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[615,400;615,365;675,365])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[550,100;575,100])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[725,355;750,355])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[795,285;820,285])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[710,230;710,295;745,295])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[420,425;455,425])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;290,435;370,435])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'hide name',0,...
		'position',[595,97,730,213])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']],...
		'position',[930,100,935,105])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']],...
		'position',[870,185,875,190])


%     Subsystem  ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Output Width','3')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[240,88,440,162])

add_block('built-in/Inport',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']],...
		'position',[160,115,180,135])

add_block('built-in/Clock',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']],...
		'position',[150,168,190,202])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[195,185;590,185])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,115;755,115])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,155;755,155])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,195;755,195])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[185,125;235,125])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[445,125;590,125])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES + CHAMP REEL')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'hide name',0,...
		'position',[85,64,285,156])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']],...
		'position',[460,65,465,70])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']],...
		'position',[455,95,460,100])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Champ rel']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES/Champ rel']],...
		'position',[425,125,430,130])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],[290,80;355,80])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],[290,110;355,110])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],[290,140;355,140])
add_line([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],[50,110;80,110])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES')


%     Finished composite block ['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES'].

set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/CHAMP ET DERIVEE',13,' PULSES']],...
		'position',[70,193,210,267])

add_block('built-in/Inport',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/in_1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/in_1'],...
		'position',[15,220,35,240])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[130,345,135,350])

add_block('built-in/Mux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux3'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux3'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[255,284,290,366])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/B''']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/B''']],...
		'position',[425,180,430,185])

add_block('built-in/Mux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux'],...
		'hide name',0,...
		'inputs','[3 3 3 3]',...
		'position',[510,181,545,364])

add_block('built-in/Derivative',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Derivative'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Derivative'],...
		'position',[435,329,480,351])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/B''c']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/B''c']],...
		'position',[495,310,500,315])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/B'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/B'],...
		'position',[240,275,245,280])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[400,97,405,102])

add_block('built-in/Demux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Demux1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[655,195,695,335])

add_block('built-in/Mux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux2'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[755,194,785,336])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[770,155,850,175])

add_block('built-in/Constant',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant'],...
		'Value','0',...
		'position',[715,255,735,275])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace3'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[755,350,835,370])

add_block('built-in/Mux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[840,202,890,453])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Couple magntique',13,'']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[920,313,980,347])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1020,245,1100,265])

add_block('built-in/Outport',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Outport'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Outport'],...
		'position',[1110,345,1130,365])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Sortie du couple gnr',13,'par la commande drive de B',13,' et rappel sur champ de consigne']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Sortie du couple gnr',13,'par la commande drive de B',13,' et rappel sur champ de consigne']],...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Sortie du couple gnr',13,'par la commande drive de B',13,' et rappel sur champ de consigne']],...
		'Font Size',12,...
		'position',[1030,160,1035,165])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Couple roue'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Couple roue'],...
		'position',[785,445,790,450])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Puls',13,'linaire']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Puls',13,'linaire']],...
		'position',[335,210,340,215])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/B '])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/B '],...
		'position',[485,225,490,230])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Pulse crneau'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Pulse crneau'],...
		'position',[305,180,310,185])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Sortie couple roue'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Sortie couple roue'],...
		'hide name',0,...
		'position',[1095,530,1100,535])

add_block('built-in/Outport',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Outport1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Outport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[1120,495,1140,515])

add_block('built-in/Mux',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux4'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[965,420,1000,480])

add_block('built-in/Sum',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Sum'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Sum'],...
		'hide name',0,...
		'position',[1050,309,1080,396])

add_block('built-in/Constant',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant1'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[925,420,945,440])

add_block('built-in/Constant',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant2'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[925,460,945,480])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace2'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace2'],...
		'hide name',0,...
		'mat-name','Cr',...
		'buffer','points_trace',...
		'position',[1045,540,1125,560])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Moments ',13,'magntiques',13,' gnrer',13,'et couple roue']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Moments ',13,'magntiques',13,' gnrer',13,'et couple roue']],...
		'MATLAB Fcn','laurens1(u)',...
		'Output Width','3',...
		'position',[570,258,630,292])

add_block('built-in/MATLAB Fcn',[sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Moments',13,'magntique',13,'de',13,'consigne',13,'']])
set_param([sys,'/',['Bloc de Laurens 1/Calcul des commandes, moments et roue/Moments',13,'magntique',13,'de',13,'consigne',13,'']],...
		'MATLAB Fcn','Bconsign(u)',...
		'Output Width','3',...
		'position',[315,308,375,342])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Bc'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/Bc'],...
		'position',[465,270,470,275])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace4'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace4'],...
		'hide name',0,...
		'mat-name','Bc',...
		'buffer','points_trace',...
		'position',[530,434,595,456])

add_block('built-in/To Workspace',[sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace5'])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue/To Workspace5'],...
		'hide name',0,...
		'mat-name','Bc_prime',...
		'buffer','points_trace',...
		'position',[530,404,595,426])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[700,220;750,220])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[700,265;705,265;705,550;1040,550])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[700,310;750,310])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[790,265;835,265])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[40,230;65,230])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[895,330;915,330])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[985,330;1045,330])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[985,330;985,255;1015,255])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[215,205;505,205])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[215,230;465,230;465,250;505,250])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[215,255;390,255;390,390;835,390])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[40,230;40,345;250,345])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[295,325;310,325])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[550,275;565,275])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[380,325;410,325;410,295;505,295])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[485,340;505,340])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[410,325;410,340;430,340])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[635,275;650,265])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[230,230;230,305;250,305])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[735,310;735,360;750,360])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[730,220;730,165;765,165])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[740,265;750,265])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[1085,355;1105,355])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[705,505;1115,505])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[905,505;905,450;960,450])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[950,430;960,430])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[950,470;960,470])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[1005,450;1030,450;1030,375;1045,375])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[380,325;380,445;525,445])
add_line([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],[485,340;485,415;525,415])
set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],...
		'Mask Display','REGULATION BOUSSOLE\n\nTECHNIQUE LAURENS\n\nPULSEE TYPE 2')


%     Finished composite block 'Bloc de Laurens 1/Calcul des commandes, moments et roue'.

set_param([sys,'/','Bloc de Laurens 1/Calcul des commandes, moments et roue'],...
		'position',[150,176,380,254])

add_block('built-in/Gain',[sys,'/','Bloc de Laurens 1/Gain3'])
set_param([sys,'/','Bloc de Laurens 1/Gain3'],...
		'hide name',0,...
		'position',[695,178,735,212])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['Bloc de Laurens 1/Suppression de',13,'tous les couples']],...
		'position',[725,135,730,140])

add_block('built-in/State-Space',[sys,'/',['Bloc de Laurens 1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['Bloc de Laurens 1/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['Bloc de Laurens 1/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[545,172,645,218])

add_block('built-in/Gain',[sys,'/','Bloc de Laurens 1/Gain2'])
set_param([sys,'/','Bloc de Laurens 1/Gain2'],...
		'hide name',0,...
		'position',[455,180,500,210])

add_block('built-in/Outport',[sys,'/','Bloc de Laurens 1/out_2'])
set_param([sys,'/','Bloc de Laurens 1/out_2'],...
		'Port','2',...
		'position',[875,390,895,410])

add_block('built-in/Note',[sys,'/','Bloc de Laurens 1/Sortie couple roue'])
set_param([sys,'/','Bloc de Laurens 1/Sortie couple roue'],...
		'ForeGround',1,...
		'position',[690,375,695,380])

add_block('built-in/Note',[sys,'/',['Bloc de Laurens 1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['Bloc de Laurens 1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[100,110,105,115])
add_line([sys,'/','Bloc de Laurens 1'],[650,195;690,195])
add_line([sys,'/','Bloc de Laurens 1'],[505,195;540,195])
add_line([sys,'/','Bloc de Laurens 1'],[105,215;145,215])
add_line([sys,'/','Bloc de Laurens 1'],[105,315;785,315])
add_line([sys,'/','Bloc de Laurens 1'],[740,195;760,195;760,290;785,290])
add_line([sys,'/','Bloc de Laurens 1'],[825,305;860,305])
add_line([sys,'/','Bloc de Laurens 1'],[850,305;850,370;830,370])
add_line([sys,'/','Bloc de Laurens 1'],[385,195;450,195])
add_line([sys,'/','Bloc de Laurens 1'],[385,235;470,235;470,400;870,400])
set_param([sys,'/','Bloc de Laurens 1'],...
		'Mask Display','REGULATION "BPOINT"\n\nDE M LAURENS\n\n2 BOBINES ET UNE ROUE',...
		'Mask Help','Bloc pris dans reg_derB en "BPOINT"')


%     Finished composite block 'Bloc de Laurens 1'.

set_param([sys,'/','Bloc de Laurens 1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[135,288,365,392])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[390,302,415,328])


%     Subsystem  'Stops1'.

new_system([sys,'/','Stops1'])
set_param([sys,'/','Stops1'],'Location',[64,144,1175,796])

add_block('built-in/Inport',[sys,'/','Stops1/in_1'])
set_param([sys,'/','Stops1/in_1'],...
		'position',[75,225,95,245])

add_block('built-in/Constant',[sys,'/','Stops1/Constant2'])
set_param([sys,'/','Stops1/Constant2'],...
		'Value','angle_mini_mod_fin',...
		'position',[270,134,440,156])

add_block('built-in/Demux',[sys,'/','Stops1/Demux1'])
set_param([sys,'/','Stops1/Demux1'],...
		'outputs','[3 3]',...
		'position',[240,207,280,263])

add_block('built-in/MATLAB Fcn',[sys,'/','Stops1/fpqrQ_V_P1'])
set_param([sys,'/','Stops1/fpqrQ_V_P1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'Mask Display','pqrQ_V_P',...
		'position',[125,214,195,256])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops1/Valeur absolue',13,'des angles1']])
set_param([sys,'/',['Stops1/Valeur absolue',13,'des angles1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil angulaire',...
		'position',[335,196,430,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops1/Valeur absolue',13,'des angles2']])
set_param([sys,'/',['Stops1/Valeur absolue',13,'des angles2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil  vitesse angulaire')
set_param([sys,'/',['Stops1/Valeur absolue',13,'des angles2']],...
		'position',[330,390,465,440])

add_block('built-in/Constant',[sys,'/','Stops1/Constant3'])
set_param([sys,'/','Stops1/Constant3'],...
		'Value','vitesse_angul_mini',...
		'position',[310,329,480,351])

add_block('built-in/Relational Operator',[sys,'/',['Stops1/Relational',13,'Operator1']])
set_param([sys,'/',['Stops1/Relational',13,'Operator1']],...
		'position',[505,108,545,257])

add_block('built-in/Relational Operator',[sys,'/',['Stops1/Relational',13,'Operator2']])
set_param([sys,'/',['Stops1/Relational',13,'Operator2']],...
		'position',[510,303,550,452])

add_block('built-in/Note',[sys,'/',['Stops1/CONTROLEURS DE DEROULEMENT ',13,'']])
set_param([sys,'/',['Stops1/CONTROLEURS DE DEROULEMENT ',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[415,25,420,30])

add_block('built-in/Product',[sys,'/','Stops1/Product'])
set_param([sys,'/','Stops1/Product'],...
		'position',[750,169,775,231])

add_block('built-in/Note',[sys,'/','Stops1/Contrle du seuil angulaire'])
set_param([sys,'/','Stops1/Contrle du seuil angulaire'],...
		'ForeGround',1,...
		'position',[655,155,660,160])

add_block('built-in/Note',[sys,'/','Stops1/Contrle du seuil de vitesse'])
set_param([sys,'/','Stops1/Contrle du seuil de vitesse'],...
		'ForeGround',1,...
		'position',[650,390,655,395])


%     Subsystem  'Stops1/Stop detumbling2'.

new_system([sys,'/','Stops1/Stop detumbling2'])
set_param([sys,'/','Stops1/Stop detumbling2'],'Location',[769,541,1204,644])

add_block('built-in/Inport',[sys,'/','Stops1/Stop detumbling2/in_1'])
set_param([sys,'/','Stops1/Stop detumbling2/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops1/Stop detumbling2/Gain'])
set_param([sys,'/','Stops1/Stop detumbling2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops1/Stop detumbling2/Stop Simulation'])
set_param([sys,'/','Stops1/Stop detumbling2/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops1/Stop detumbling2/Stop dsamorable'])
set_param([sys,'/','Stops1/Stop detumbling2/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops1/Stop detumbling2'],[155,65;225,65])
add_line([sys,'/','Stops1/Stop detumbling2'],[315,65;345,65])
set_param([sys,'/','Stops1/Stop detumbling2'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops1/Stop detumbling2'.

set_param([sys,'/','Stops1/Stop detumbling2'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[880,175,1075,225])


%     Subsystem  'Stops1/Stop detumbling3'.

new_system([sys,'/','Stops1/Stop detumbling3'])
set_param([sys,'/','Stops1/Stop detumbling3'],'Location',[724,654,1159,757])

add_block('built-in/Inport',[sys,'/','Stops1/Stop detumbling3/in_1'])
set_param([sys,'/','Stops1/Stop detumbling3/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops1/Stop detumbling3/Gain'])
set_param([sys,'/','Stops1/Stop detumbling3/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops1/Stop detumbling3/Stop Simulation'])
set_param([sys,'/','Stops1/Stop detumbling3/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops1/Stop detumbling3/Stop dsamorable'])
set_param([sys,'/','Stops1/Stop detumbling3/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops1/Stop detumbling3'],[155,65;225,65])
add_line([sys,'/','Stops1/Stop detumbling3'],[315,65;345,65])
set_param([sys,'/','Stops1/Stop detumbling3'],...
		'Mask Display','STOP DU MODE "Bpoint"\n\nDESAMORCABLE')


%     Finished composite block 'Stops1/Stop detumbling3'.

set_param([sys,'/','Stops1/Stop detumbling3'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[870,353,1085,407])

add_block('built-in/Note',[sys,'/','Stops1/ui'])
set_param([sys,'/','Stops1/ui'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[460,485,465,490])
add_line([sys,'/','Stops1'],[100,235;120,235])
add_line([sys,'/','Stops1'],[200,235;235,235])
add_line([sys,'/','Stops1'],[445,145;500,145])
add_line([sys,'/','Stops1'],[435,220;500,220])
add_line([sys,'/','Stops1'],[285,220;330,220])
add_line([sys,'/','Stops1'],[285,250;300,250;300,415;325,415])
add_line([sys,'/','Stops1'],[555,380;865,380])
add_line([sys,'/','Stops1'],[470,415;505,415])
add_line([sys,'/','Stops1'],[485,340;505,340])
add_line([sys,'/','Stops1'],[550,185;745,185])
add_line([sys,'/','Stops1'],[650,380;650,215;745,215])
add_line([sys,'/','Stops1'],[780,200;875,200])
set_param([sys,'/','Stops1'],...
		'Mask Display','STOP DE SIMULATION\nSUR SEUIL ANGULAIRE\n( angle mini_mod_fin )')


%     Finished composite block 'Stops1'.

set_param([sys,'/','Stops1'],...
		'ForeGround',1,...
		'hide name',0,...
		'position',[985,188,1195,242])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[8,66,1236,792])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou janvier 2014'])
set_param([sys,'/','Subsystem1/Robert Guiziou janvier 2014'],...
		'ForeGround',2,...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est totale1.m']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est totale1.m']],...
		'Font Size',14,...
		'position',[405,125,410,130])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,90,500,95])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes totdatNP ( sans pulse ) ou totdatP ( avec pulse ) '])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes totdatNP ( sans pulse ) ou totdatP ( avec pulse ) '],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[680,210,685,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  100000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  100000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[565,235,570,240])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[305,265,310,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop ( paramtrable ) arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop ( paramtrable ) arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[530,295,535,300])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'])
set_param([sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'],...
		'Font Size',14,...
		'position',[550,400,555,405])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[335,365,340,370])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[550,515,555,520])

add_block('built-in/Note',[sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '])
set_param([sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[375,610,380,615])

add_block('built-in/Note',[sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'])
set_param([sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[920,610,925,615])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[835,810,1185,851])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','RETROUVER LES PRINCIPALES CARACTERISTIQUES DANS L''ESPACE MATLAB',...
		'Mask Dialogue','eval(''display'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[105,820,790,856])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[880,593,915,627])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\n(totdatP.m)\n par double clic souris\nCAS PULSE',...
		'Mask Dialogue','eval(''puldatP'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1015,680,1230,771])


%     Subsystem  'Graphes'.

new_system([sys,'/','Graphes'])
set_param([sys,'/','Graphes'],'Location',[36,544,1176,989])


%     Subsystem  'Graphes/Extras27'.

new_system([sys,'/','Graphes/Extras27'])
set_param([sys,'/','Graphes/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras27'.

set_param([sys,'/','Graphes/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,240,220,301])


%     Subsystem  'Graphes/Extras22'.

new_system([sys,'/','Graphes/Extras22'])
set_param([sys,'/','Graphes/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras22'.

set_param([sys,'/','Graphes/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphes/Extras29'.

new_system([sys,'/','Graphes/Extras29'])
set_param([sys,'/','Graphes/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras29'.

set_param([sys,'/','Graphes/Extras29'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphes/Extras21'.

new_system([sys,'/','Graphes/Extras21'])
set_param([sys,'/','Graphes/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras21'.

set_param([sys,'/','Graphes/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphes/Extras20'.

new_system([sys,'/','Graphes/Extras20'])
set_param([sys,'/','Graphes/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras20'.

set_param([sys,'/','Graphes/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])


%     Subsystem  'Graphes/Extras30'.

new_system([sys,'/','Graphes/Extras30'])
set_param([sys,'/','Graphes/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras30'.

set_param([sys,'/','Graphes/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphes/Extras34'.

new_system([sys,'/','Graphes/Extras34'])
set_param([sys,'/','Graphes/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras34'.

set_param([sys,'/','Graphes/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphes/Extras32'.

new_system([sys,'/','Graphes/Extras32'])
set_param([sys,'/','Graphes/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras32'.

set_param([sys,'/','Graphes/Extras32'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphes/Extras23'.

new_system([sys,'/','Graphes/Extras23'])
set_param([sys,'/','Graphes/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras23'.

set_param([sys,'/','Graphes/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphes/Extras24'.

new_system([sys,'/','Graphes/Extras24'])
set_param([sys,'/','Graphes/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras24'.

set_param([sys,'/','Graphes/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphes/Extras25'.

new_system([sys,'/','Graphes/Extras25'])
set_param([sys,'/','Graphes/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras25'.

set_param([sys,'/','Graphes/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphes/Extras26'.

new_system([sys,'/','Graphes/Extras26'])
set_param([sys,'/','Graphes/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphes/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphes/Extras26'.

set_param([sys,'/','Graphes/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphes/Extras28'.

new_system([sys,'/','Graphes/Extras28'])
set_param([sys,'/','Graphes/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras28'.

set_param([sys,'/','Graphes/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphes/Extras31'.

new_system([sys,'/','Graphes/Extras31'])
set_param([sys,'/','Graphes/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras31'.

set_param([sys,'/','Graphes/Extras31'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphes/Extras33'.

new_system([sys,'/','Graphes/Extras33'])
set_param([sys,'/','Graphes/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras33'.

set_param([sys,'/','Graphes/Extras33'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])

add_block('built-in/Note',[sys,'/','Graphes/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphes/SORTIES GRAPHIQUES'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[535,25,540,30])

add_block('built-in/Note',[sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[545,85,550,90])
set_param([sys,'/','Graphes'],...
		'Mask Display','SORTIES\n\nGRAPHIQUES')


%     Finished composite block 'Graphes'.

set_param([sys,'/','Graphes'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[1010,580,1225,656])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[940,265,945,270])


%     Subsystem  'Sorties numriques et graphiques'.

new_system([sys,'/','Sorties numriques et graphiques'])
set_param([sys,'/','Sorties numriques et graphiques'],'Location',[4,57,1267,954])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Sorties numriques et graphiques/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Sorties numriques et graphiques/Demux'])
set_param([sys,'/','Sorties numriques et graphiques/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties numriques et graphiques/MATLAB Fcn1'])
set_param([sys,'/','Sorties numriques et graphiques/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace14'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace12'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Sorties numriques et graphiques/Demux2'])
set_param([sys,'/','Sorties numriques et graphiques/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Sorties numriques et graphiques/Energie'])
set_param([sys,'/','Sorties numriques et graphiques/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Sorties numriques et graphiques/Drive de Q'])
set_param([sys,'/','Sorties numriques et graphiques/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/','Sorties numriques et graphiques/Quaternion Q'])
set_param([sys,'/','Sorties numriques et graphiques/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace5'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Sorties numriques et graphiques/Mux'])
set_param([sys,'/','Sorties numriques et graphiques/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/Q''']])
set_param([sys,'/',['Sorties numriques et graphiques/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Sorties numriques et graphiques/Q'])
set_param([sys,'/','Sorties numriques et graphiques/Q'],...
		'position',[705,590,710,595])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties numriques et graphiques/MATLAB Fcn3'])
set_param([sys,'/','Sorties numriques et graphiques/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Demux',[sys,'/','Sorties numriques et graphiques/Demux1'])
set_param([sys,'/','Sorties numriques et graphiques/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Sorties numriques et graphiques/in_1'])
set_param([sys,'/','Sorties numriques et graphiques/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace13'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Sorties numriques et graphiques/To File'])
set_param([sys,'/','Sorties numriques et graphiques/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Sorties numriques et graphiques/To File1'])
set_param([sys,'/','Sorties numriques et graphiques/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To File',[sys,'/','Sorties numriques et graphiques/To File2'])
set_param([sys,'/','Sorties numriques et graphiques/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/Demux',[sys,'/','Sorties numriques et graphiques/Demux3'])
set_param([sys,'/','Sorties numriques et graphiques/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace15'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace16'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace17'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Sorties numriques et graphiques/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Sorties numriques et graphiques/in_2'])
set_param([sys,'/','Sorties numriques et graphiques/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Sorties numriques et graphiques/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Sorties numriques et graphiques/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Sorties numriques et graphiques/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[900,565,905,570])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace7'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[860,370,930,390])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/Entre de',13,'p q r Q']])
set_param([sys,'/',['Sorties numriques et graphiques/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[410,455,415,460])

add_block('built-in/To File',[sys,'/','Sorties numriques et graphiques/To File4'])
set_param([sys,'/','Sorties numriques et graphiques/To File4'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ')
set_param([sys,'/','Sorties numriques et graphiques/To File4'],...
		'position',[180,357,335,413])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace11'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[985,624,1070,656])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties numriques et graphiques/MATLAB Fcn4'])
set_param([sys,'/','Sorties numriques et graphiques/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[885,621,965,659])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties numriques et graphiques/MATLAB Fcn5'])
set_param([sys,'/','Sorties numriques et graphiques/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[1000,731,1080,769])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace18'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_relative',...
		'buffer','points_trace',...
		'position',[1100,737,1235,763])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/To Workspace9'])
set_param([sys,'/','Sorties numriques et graphiques/To Workspace9'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','initpqrQ_final',...
		'buffer','1',...
		'position',[300,292,390,318])


%     Subsystem  'Sorties numriques et graphiques/Subsystem'.

new_system([sys,'/','Sorties numriques et graphiques/Subsystem'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem'],'Location',[15,70,530,365])

add_block('built-in/Note',[sys,'/',['Sorties numriques et graphiques/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']])
set_param([sys,'/',['Sorties numriques et graphiques/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['Sorties numriques et graphiques/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']],...
		'position',[255,35,260,40])

add_block('built-in/Constant',[sys,'/','Sorties numriques et graphiques/Subsystem/Constant'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/Constant'],...
		'hide name',0,...
		'Value','vitesse_angul_mini',...
		'position',[80,104,215,126])

add_block('built-in/Constant',[sys,'/','Sorties numriques et graphiques/Subsystem/Constant1'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/Constant1'],...
		'hide name',0,...
		'Value','vitesse_angul_mini0',...
		'position',[80,139,215,161])

add_block('built-in/Relational Operator',[sys,'/',['Sorties numriques et graphiques/Subsystem/Relational',13,'Operator']])
set_param([sys,'/',['Sorties numriques et graphiques/Subsystem/Relational',13,'Operator']],...
		'hide name',0,...
		'Operator','<=',...
		'position',[265,96,290,169])

add_block('built-in/Product',[sys,'/','Sorties numriques et graphiques/Subsystem/Product'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/Product'],...
		'hide name',0,...
		'position',[335,110,360,205])

add_block('built-in/To File',[sys,'/','Sorties numriques et graphiques/Subsystem/To File4'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/To File4'],...
		'hide name',0,...
		'File name','B_point.mat',...
		'Matrix name','temps_Bpoint',...
		'position',[395,137,485,183])

add_block('built-in/Clock',[sys,'/','Sorties numriques et graphiques/Subsystem/Clock1'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/Clock1'],...
		'hide name',0,...
		'position',[80,203,140,257])

add_block('built-in/To Workspace',[sys,'/','Sorties numriques et graphiques/Subsystem/To Workspace9'])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[160,180,230,200])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[365,160;390,160])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[145,230;245,230;245,180;330,180])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[295,135;330,135])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[220,150;260,150])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[220,115;260,115])
add_line([sys,'/','Sorties numriques et graphiques/Subsystem'],[145,230;155,190])
set_param([sys,'/','Sorties numriques et graphiques/Subsystem'],...
		'Mask Display','TEMPS B_POINT')


%     Finished composite block 'Sorties numriques et graphiques/Subsystem'.

set_param([sys,'/','Sorties numriques et graphiques/Subsystem'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[175,515,395,574])


%     Subsystem  ['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES'].

new_system([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']])
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES/x']])
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],[90,65;125,65])
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])')
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'Mask Entries','6000\/-200\/200\/''y-/m--/c-./w+''\/')


%     Finished composite block ['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES'].

set_param([sys,'/',['Sorties numriques et graphiques/ANGLES',13,'EN DEGRES']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[590,742,680,798])
add_line([sys,'/','Sorties numriques et graphiques'],[525,380;740,380])
add_line([sys,'/','Sorties numriques et graphiques'],[830,380;855,380])
add_line([sys,'/','Sorties numriques et graphiques'],[425,425;465,425])
add_line([sys,'/','Sorties numriques et graphiques'],[525,465;695,465])
add_line([sys,'/','Sorties numriques et graphiques'],[415,625;465,625])
add_line([sys,'/','Sorties numriques et graphiques'],[525,580;560,580])
add_line([sys,'/','Sorties numriques et graphiques'],[525,665;730,665])
add_line([sys,'/','Sorties numriques et graphiques'],[675,465;675,615;730,615])
add_line([sys,'/','Sorties numriques et graphiques'],[775,640;880,640])
add_line([sys,'/','Sorties numriques et graphiques'],[970,640;980,640])
add_line([sys,'/','Sorties numriques et graphiques'],[765,465;775,465])
add_line([sys,'/','Sorties numriques et graphiques'],[810,465;855,465])
add_line([sys,'/','Sorties numriques et graphiques'],[910,430;960,430])
add_line([sys,'/','Sorties numriques et graphiques'],[910,465;960,465])
add_line([sys,'/','Sorties numriques et graphiques'],[910,500;960,500])
add_line([sys,'/','Sorties numriques et graphiques'],[945,430;945,400;1110,400])
add_line([sys,'/','Sorties numriques et graphiques'],[943,465;945,450;1110,450])
add_line([sys,'/','Sorties numriques et graphiques'],[945,500;945,515;1110,515])
add_line([sys,'/','Sorties numriques et graphiques'],[550,380;550,210;605,210])
add_line([sys,'/','Sorties numriques et graphiques'],[660,175;710,175])
add_line([sys,'/','Sorties numriques et graphiques'],[660,210;710,210])
add_line([sys,'/','Sorties numriques et graphiques'],[660,245;710,245])
add_line([sys,'/','Sorties numriques et graphiques'],[1085,750;1095,750])
add_line([sys,'/','Sorties numriques et graphiques'],[970,640;970,750;995,750])
add_line([sys,'/','Sorties numriques et graphiques'],[440,425;440,385;340,385])
add_line([sys,'/','Sorties numriques et graphiques'],[830,465;830,770;685,770])
add_line([sys,'/','Sorties numriques et graphiques'],[435,385;435,305;395,305])
set_param([sys,'/','Sorties numriques et graphiques'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES\n\nENERGIE\n\n& TRANSFERT DE initpqrQ')


%     Finished composite block 'Sorties numriques et graphiques'.

set_param([sys,'/','Sorties numriques et graphiques'],...
		'ForeGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[1020,276,1210,369])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[765,535,770,540])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[710,610,715,615])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[780,220,815,680])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[715,415,720,420])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[705,281,720,419])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[570,415,590,675])


%     Subsystem  ['Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],'Location',[4,166,1267,899])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inport']],...
		'position',[10,485,30,505])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'ForeGround',1)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',18)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[400,35,405,40])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/B']],...
		'position',[480,425,485,430])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[110,515,115,520])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[770,382,805,408])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[850,399,855,404])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[660,277,665,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[740,438,800,472])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[345,315,460,365])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[865,440,985,470])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[215,246,220,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[610,378,670,412])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[510,286,555,504])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[290,288,320,392])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[100,293,245,317])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[100,328,245,352])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[100,363,245,387])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/M']],...
		'position',[495,315,500,320])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[755,318,900,342])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[755,283,900,307])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[755,248,900,272])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[945,243,975,347])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,195,870,200])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[765,158,910,182])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[765,123,910,147])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[765,88,910,112])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[955,83,985,187])


%     Subsystem  ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[231,269,1077,738])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'position',[190,95,365,145])

add_block('built-in/Clock',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[120,104,155,136])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[280,70,285,75])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']],...
		'position',[730,220,735,225])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[125,205,130,210])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[145,65,150,70])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']],...
		'hide name',0,...
		'mat-name','BY',...
		'buffer','points_trace',...
		'position',[515,32,565,48])

add_block('built-in/Demux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']],...
		'outputs','3',...
		'position',[440,24,480,56])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[370,120;480,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[160,120;185,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[395,120;395,40;435,40])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[485,40;510,40])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[210,458,410,532])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3',...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'position',[600,554,775,606])

add_block('built-in/Sum',[sys,'/',['Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1055,254,1090,361])

add_block('built-in/State-Space',[sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'ForeGround',1,...
		'BackGround',3,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'Mask Type','Matrix Gain',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'position',[1125,288,1195,332])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1225,300,1245,320])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[635,505,640,510])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[695,605,700,610])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[780,580;1020,580;1020,345;1050,345])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[35,495;205,495])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[45,495;45,580;595,580])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[990,135;1040,135;1050,270])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,330;940,330])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[980,295;1050,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,295;940,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,260;940,260])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,170;950,170])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,135;950,135])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,100;950,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,375;285,375])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,340;285,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,305;285,305])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[325,340;340,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[465,340;505,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[415,495;440,495;440,450;505,450])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[560,395;605,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[805,455;860,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[675,395;705,395;705,455;735,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[705,395;765,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[810,395;1005,400;1005,320;1050,320])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1095,310;1120,310])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1200,310;1220,310])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[140,515,375,575])


%     Subsystem  'F(X,t) pour le quaternion'.

new_system([sys,'/','F(X,t) pour le quaternion'])
set_param([sys,'/','F(X,t) pour le quaternion'],'Location',[588,239,930,345])

add_block('built-in/Note',[sys,'/',['F(X,t) pour le quaternion/Drive du quaternion d''attitude']])
set_param([sys,'/',['F(X,t) pour le quaternion/Drive du quaternion d''attitude']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','F(X,t) pour le quaternion/Outport'])
set_param([sys,'/','F(X,t) pour le quaternion/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','F(X,t) pour le quaternion/Inport'])
set_param([sys,'/','F(X,t) pour le quaternion/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour le quaternion/deriv_qt.m'])
set_param([sys,'/','F(X,t) pour le quaternion/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','F(X,t) pour le quaternion'],[225,55;255,55])
add_line([sys,'/','F(X,t) pour le quaternion'],[105,55;145,55])
set_param([sys,'/','F(X,t) pour le quaternion'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'F(X,t) pour le quaternion'.

set_param([sys,'/','F(X,t) pour le quaternion'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[140,702,375,768])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[530,191,1137,462])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'ForeGround',1,...
		'position',[190,115,195,120])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)')
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'position',[240,116,375,174])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/in_1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[30,165,50,185])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'outputs','[3 4]',...
		'position',[90,118,135,227])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'ForeGround',1,...
		'position',[160,180,165,185])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q non utilis'])
set_param([sys,'/','F(X,t) pour la rotation/Q non utilis'],...
		'ForeGround',1,...
		'position',[180,210,185,215])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_2'])
set_param([sys,'/','F(X,t) pour la rotation/out_2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[450,135,470,155])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,30,295,35])
add_line([sys,'/','F(X,t) pour la rotation'],[380,145;445,145])
add_line([sys,'/','F(X,t) pour la rotation'],[140,145;235,145])
add_line([sys,'/','F(X,t) pour la rotation'],[55,175;85,175])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X,t)\n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[140,594,375,666])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[740,775,745,780])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[435,780,440,785])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[180,775,185,780])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[765,305,770,310])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[935,315,940,320])
add_line(sys,[370,315;385,315])
add_line(sys,[965,450;975,450;975,780;50,780;50,315;130,315])
add_line(sys,[380,735;620,735;620,565;775,565])
add_line(sys,[595,545;650,545;650,385;700,385])
add_line(sys,[610,315;700,315])
add_line(sys,[965,450;975,450;975,300;1015,300])
add_line(sys,[50,735;135,735])
add_line(sys,[50,630;135,630])
add_line(sys,[50,545;135,545])
add_line(sys,[50,490;130,490])
add_line(sys,[380,630;565,630])
add_line(sys,[380,545;565,545])
add_line(sys,[375,475;520,475;520,460;565,460])
add_line(sys,[725,350;750,350;750,335;775,335])
add_line(sys,[975,415;1005,415])
add_line(sys,[820,450;835,450;835,345;1015,345])
add_line(sys,[835,450;855,450])
add_line(sys,[420,315;455,315])
add_line(sys,[370,365;390,365;390,415;100,415;100,460;130,460])
add_line(sys,[85,365;130,365])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
